@@ -1,5 +1,5 @@
 /*
- *  megatools - Mega.co.nz client library and tools
+ *  megatools - Mega.nz client library and tools
  *  Copyright (C) 2013  Ondřej Jirman <megous@megous.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -21,10 +21,6 @@
 #define __MEGA_H__
 
 #include <mega/mega-rsa-key.h>
-#include <mega/mega-http-io-stream.h>
-#include <mega/mega-http-input-stream.h>
-#include <mega/mega-http-output-stream.h>
-#include <mega/mega-http-client.h>
 #include <mega/mega-chunked-cbc-mac.h>
 #include <mega/mega-aes-ctr-encryptor.h>
 #include <mega/utils.h>
