@@ -1,5 +1,5 @@
 #
-# megatools - Mega.co.nz client library and tools
+# megatools - Mega.nz client library and tools
 # Copyright (C) 2013  Ondřej Jirman <megous@megous.com>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -28,7 +28,3 @@ print(pkey.get_ubase64())
 
 print(Mega.format_hex(pkey.get_enc_binary(mkey), Mega.HexFormat.PACKED))
 print(Mega.format_hex(mkey.encrypt_raw(pkey.get_binary()), Mega.HexFormat.PACKED))
-
-http = Mega.HttpClient.new()
-x = http.post_simple('http://localhost', b'qwe')
-print(x.str)
