@@ -1,5 +1,5 @@
 /*
- *  megatools - Mega.co.nz client library and tools
+ *  megatools - Mega.nz client library and tools
  *  Copyright (C) 2013  Ondřej Jirman <megous@megous.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -54,7 +54,7 @@ int main(int ac, char* av[])
   GError *local_err = NULL;
   mega_session* s;
 
-  tool_init(&ac, &av, "- display mega.co.nz storage quotas/usage", entries);
+  tool_init(&ac, &av, "- display mega.nz storage quotas/usage", entries);
 
   if (opt_total || opt_free || opt_used)
   {
