@@ -1,5 +1,5 @@
 /*
- *  megatools - Mega.co.nz client library and tools
+ *  megatools - Mega.nz client library and tools
  *  Copyright (C) 2013  Ondřej Jirman <megous@megous.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -151,7 +151,7 @@ int main(int ac, char* av[])
   gint i;
   int status = 0;
 
-  tool_init_bare(&ac, &av, "- download exported files from mega.co.nz", entries);
+  tool_init_bare(&ac, &av, "- download exported files from mega.nz", entries);
 
   if (!strcmp(opt_path, "-"))
   {
@@ -179,10 +179,10 @@ int main(int ac, char* av[])
 
   // prepare link parsers
 
-  file_regex = g_regex_new("^https?://mega.co.nz/#!([a-z0-9_-]{8})!([a-z0-9_-]{43})$", G_REGEX_CASELESS, 0, NULL);
+  file_regex = g_regex_new("^https?://mega(?:\\.co)?\\.nz/#!([a-z0-9_-]{8})!([a-z0-9_-]{43})$", G_REGEX_CASELESS, 0, NULL);
   g_assert(file_regex != NULL);
 
-  folder_regex = g_regex_new("^https?://mega.co.nz/#F!([a-z0-9_-]{8})!([a-z0-9_-]{22})$", G_REGEX_CASELESS, 0, NULL);
+  folder_regex = g_regex_new("^https?://mega(?:\\.co)?\\.nz/#F!([a-z0-9_-]{8})!([a-z0-9_-]{22})$", G_REGEX_CASELESS, 0, NULL);
   g_assert(folder_regex != NULL);
 
   // create session
