@@ -1,5 +1,5 @@
 /*
- *  megatools - Mega.co.nz client library and tools
+ *  megatools - Mega.nz client library and tools
  *  Copyright (C) 2013  Ondřej Jirman <megous@megous.com>
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -98,7 +98,7 @@ int main(int ac, char* av[])
   gc_free gchar* signup_key = NULL;
   mega_session* s;
 
-  tool_init_bare(&ac, &av, "LINK - register a new mega.co.nz account", entries);
+  tool_init_bare(&ac, &av, "LINK - register a new mega.nz account", entries);
 
   if (opt_verify && opt_register)
   {
@@ -110,19 +110,19 @@ int main(int ac, char* av[])
   {
     if (!opt_name)
     {
-      g_printerr("ERROR: You must specify name for your new mega.co.nz account\n");
+      g_printerr("ERROR: You must specify name for your new mega.nz account\n");
       return 1;
     }
 
     if (!opt_email)
     {
-      g_printerr("ERROR: You must specify email for your new mega.co.nz account\n");
+      g_printerr("ERROR: You must specify email for your new mega.nz account\n");
       return 1;
     }
 
     if (!opt_password)
     {
-      g_printerr("ERROR: You must specify password for your new mega.co.nz account\n");
+      g_printerr("ERROR: You must specify password for your new mega.nz account\n");
       return 1;
     }
 
@@ -135,7 +135,7 @@ int main(int ac, char* av[])
       return 1;
     }
 
-    gc_regex_unref GRegex* r = g_regex_new("^(?:https?://mega.co.nz/#confirm)?([a-z0-9_-]{80,150})$", G_REGEX_CASELESS, 0, NULL);
+    gc_regex_unref GRegex* r = g_regex_new("^(?:https?://mega(?:\\.co)?\\.nz/#confirm)?([a-z0-9_-]{80,150})$", G_REGEX_CASELESS, 0, NULL);
     gc_match_info_unref GMatchInfo* m = NULL;
 
     g_assert(r != NULL);
